@@ -6,7 +6,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -25,6 +25,7 @@
 #include "gogcpapp.h"
 #include "gogcrystalapp.h"
 #include "gogchem3dapp.h"
+#include <gcu/glview.h>
 #include <gsf/gsf-impl-utils.h>
 #include <goffice/app/module-plugin-defs.h>
 #include <goffice/component/go-component-factory.h>
@@ -80,6 +81,46 @@ gcu_content_type_as_string (gcu::ContentType type)
 	return ret;
 }
 
+static struct {
+	gcu::Display3DMode mode;
+	char const *name;
+} display3d_modes[4] = {
+	{gcu::BALL_AND_STICK, "ball&stick"},
+	{gcu::SPACEFILL, "spacefill"},
+	{gcu::CYLINDERS, "cylinders"},
+	{gcu::WIREFRAME, "wireframe"}
+};
+
+static gcu::Display3DMode
+gcu_display3d_mode_from_str (char const *name)
+{
+	unsigned i;
+	gcu::Display3DMode ret = gcu::BALL_AND_STICK;
+
+	for (i = 0; i < 4; i++) {
+		if (strcmp (display3d_modes[i].name, name) == 0) {
+			ret = display3d_modes[i].mode;
+			break;
+		}
+	}
+	return ret;
+}
+
+char const *
+gcu_display3d_mode_as_string (gcu::Display3DMode mode)
+{
+	unsigned i;
+	char const *ret = "ball&stick";
+
+	for (i = 0; i < 4; i++) {
+		if (display3d_modes[i].mode == mode) {
+			ret = display3d_modes[i].name;
+			break;
+		}
+	}
+	return ret;
+}
+
 extern GOPluginModuleDepend const go_plugin_depends [] = {
     { "goffice", GOFFICE_API_VERSION }
 };
@@ -174,11 +215,24 @@ go_gchemutils_component_edit (GOComponent *component)
 static void
 go_gchemutils_component_mime_type_set (GOComponent *component)
 {
-/*	if (!strcmp (component->mime_type, "application/x-gcrystal") ||
-	    (!strcmp (component->mime_type, "chemical/x-xyz")) {
-		component->resizable = true;
-		component->snapshot_type = GO_SNAPSHOT_PNG;
-	}*/
+	GOGChemUtilsComponent *gogcu = GO_GCHEMUTILS_COMPONENT (component);
+	if (gogcu->type == gcu::ContentTypeUnknown) {
+		gogcu->application = Apps[component->mime_type];
+		gogcu->type = gogcu->application->GetContentType ();
+		switch (gogcu->type) {
+		case gcu::ContentType2D:
+		default:
+			component->resizable = false;
+			component->snapshot_type = GO_SNAPSHOT_SVG;
+			break;
+		case gcu::ContentType3D:
+		case gcu::ContentTypeCrystal:
+			component->resizable = true;
+			component->snapshot_type = GO_SNAPSHOT_PNG;
+			break;
+		}
+	} else
+		gogcu->application = Apps[gcu_content_type_as_string (gogcu->type)];
 }
 
 static void
@@ -199,16 +253,16 @@ go_gchemutils_component_set_property (GObject *obj, guint param_id,
 		gogcu->type = gcu_content_type_from_str (g_value_get_string (value));
 		break;
 	case GOGCU_PROP_PSI:
-		// FIXME: implement
+		gogcu->psi = g_value_get_double (value);
 		break;
 	case GOGCU_PROP_THETA:
-		// FIXME: implement
+		gogcu->theta = g_value_get_double (value);
 		break;
 	case GOGCU_PROP_PHI:
-		// FIXME: implement
+		gogcu->phi = g_value_get_double (value);
 		break;
 	case GOGCU_PROP_3DMODE:
-		// FIXME: implement
+		gogcu->mode = gcu_display3d_mode_from_str (g_value_get_string (value));
 		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
@@ -227,20 +281,16 @@ go_gchemutils_component_get_property (GObject *obj, guint param_id,
 		g_value_set_string (value, gcu_content_type_as_string (gogcu->type));
 		break;
 	case GOGCU_PROP_PSI:
-		// FIXME: return a non default when model is 3d
-		g_value_set_double (value, 70.);	       
+		g_value_set_double (value, gogcu->psi);
 		break;
 	case GOGCU_PROP_THETA:
-		// FIXME: return a non default when model is 3d
-		g_value_set_double (value, 10.);	       
+		g_value_set_double (value, gogcu->theta);
 		break;
 	case GOGCU_PROP_PHI:
-		// FIXME: return a non default when model is 3d
-		g_value_set_double (value, -90.);	       
+		g_value_set_double (value, gogcu->phi);
 		break;
 	case GOGCU_PROP_3DMODE:
-		g_value_set_string (value, "ball&stick");
-		// FIXME: implement
+		g_value_set_string (value, gcu_display3d_mode_as_string (gogcu->mode));
 		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
@@ -254,6 +304,7 @@ go_gchemutils_component_finalize (GObject *obj)
 	GOGChemUtilsComponent *gogcu = GO_GCHEMUTILS_COMPONENT (obj);
 	if (gogcu->window)
 		gogcu->window->Destroy ();
+	g_free (gogcu->data);
 	G_OBJECT_CLASS (gogcu_parent_klass)->finalize (obj);
 }
 
@@ -268,6 +319,10 @@ go_gchemutils_component_init (GOComponent *component)
 	component->width = 1.;
 	component->snapshot_type = GO_SNAPSHOT_SVG;
 	gogcu->type = gcu::ContentTypeUnknown;
+	gogcu->psi = DefaultPsi;
+	gogcu->theta = DefaultTheta;
+	gogcu->phi = DefaultPhi;
+	gogcu->mode = gcu::BALL_AND_STICK;
 }
 
 static void
@@ -288,7 +343,7 @@ go_gchemutils_component_class_init (GOComponentClass *klass)
 	klass->set_size = go_gchemutils_component_set_size;
 
 	g_object_class_install_property (obj_klass, GOGCU_PROP_TYPE,
-					 g_param_spec_string ("type", _("Type"),
+					 g_param_spec_string ("content-type", _("Content type"),
 							    _("Whether the model should be represented in 2d, 3d, or as a crystal cell"),
 							    "auto", static_cast < GParamFlags > (G_PARAM_READWRITE | GO_PARAM_PERSISTENT)));
 	g_object_class_install_property (obj_klass, 	GOGCU_PROP_PSI,
@@ -303,7 +358,7 @@ go_gchemutils_component_class_init (GOComponentClass *klass)
 					 g_param_spec_double ("phi", _("Phi"),
 							    _("Value of Euler's Φ angle"),
 							    -180., 180., -90., static_cast < GParamFlags > (G_PARAM_READWRITE | GO_PARAM_PERSISTENT)));
-	g_object_class_install_property (obj_klass, GOGCU_PROP_TYPE,
+	g_object_class_install_property (obj_klass, GOGCU_PROP_3DMODE,
 					 g_param_spec_string ("mode", _("Display mode"),
 							    _("The display mode for the molecule: \"ball&stick\", \"spacefill\", \"cylinders\", or \"wireframe\""),
 							    "ball&stick", static_cast < GParamFlags > (G_PARAM_READWRITE | GO_PARAM_PERSISTENT)));
