@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -161,21 +161,6 @@ void Application::SetCurDir (string const &dir)
 	CurDir = dir;
 }
 
-void Application::OnMail (char const *MailAddress)
-{
-	go_url_show (MailAddress);
-}
-
-void Application::ShowURI (string& uri)
-{
-	go_url_show (uri.c_str ());
-}
-
-void Application::OnLiveAssistance ()
-{
-	go_url_show ("irc://irc.gimp.net/gchemutils");
-}
-
 char const *Application::GetPixbufTypeName (string& filename, char const *mime_type)
 {
 	GdkPixbufFormat *format = m_SupportedPixbufFormats[mime_type];
