@@ -1,12 +1,12 @@
-/* 
+/*
  * Gnome Chemistry Utils
- * element.cc 
+ * element.cc
  *
  * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -68,10 +68,10 @@ class EltTable
 public:
 	EltTable();
 	virtual ~EltTable();
-	
+
 	Element* operator [] (int Z);
 	Element* operator [] (string Symbol);
-	
+
 	void AddElement(Element* Elt);
 
 private:
@@ -212,7 +212,8 @@ void EltTable::AddElement(Element* Elt)
 
 Element::Element(int Z, const char* Symbol):
 	m_AtomicWeight (NULL),
-	m_MetallicCached (false)
+	m_MetallicCached (false),
+	m_Stability (false)
 {
 	m_Z = Z;
 	strncpy(m_Symbol, Symbol, 3);
@@ -612,7 +613,7 @@ void Element::LoadElectronicProps ()
 						Elt->m_ei[rank].unit = (*it).c_str ();
 						xmlFree (buf);
 					} else
-						Elt->m_ei[rank].unit = "MJ.mol<sup>-1</sup>";
+						Elt->m_ei[rank].unit = "MJ.mol<sup>−1</sup>";
 				} else if (!strcmp ((const char*) child->name, "ae")) {
 					unsigned rank;
 					buf = (char*) xmlGetProp (child, (xmlChar*) "rank");
@@ -647,7 +648,7 @@ void Element::LoadElectronicProps ()
 						Elt->m_ae[rank].unit = (*it).c_str ();
 						xmlFree (buf);
 					} else
-						Elt->m_ae[rank].unit = "kJ.mol<sup>-1</sup>";
+						Elt->m_ae[rank].unit = "kJ.mol<sup>−1</sup>";
 				} else {
 					g_error ("Invalid property node");
 				}
@@ -711,6 +712,7 @@ void Element::LoadIsotopes ()
 					}
 					num = (char*) xmlGetProp (child, (xmlChar*) "abundance");
 					if (num) {
+						Elt->m_Stability = true;
 						ReadValue (num, Is->abundance);
 						xmlFree (num);
 						niso++;
@@ -982,6 +984,7 @@ void Element::LoadBODR ()
 			node = node->next;
 		}
 	}
+	xmlFreeDoc (xml);
 }
 
 Value const *Element::GetProperty (char const *property_name)
