@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -201,22 +201,22 @@ static void on_help (G_GNUC_UNUSED GtkWidget *widget, Chem3dWindow *window)
 
 static void on_web (G_GNUC_UNUSED GtkWidget *widget, Chem3dWindow *window)
 {
-	window->GetApplication ()->OnWeb ();
+	window->GetApplication ()->OnWeb (window->GetScreen ());
 }
 
 static void on_mail (G_GNUC_UNUSED GtkWidget *widget, Chem3dWindow *window)
 {
-	window->GetApplication ()->OnMail ();
+	window->GetApplication ()->OnMail (window->GetScreen ());
 }
 
 static void on_bug (G_GNUC_UNUSED GtkWidget *widget, Chem3dWindow *window)
 {
-	window->GetApplication ()->OnBug ();
+	window->GetApplication ()->OnBug (window->GetScreen ());
 }
 
 static void on_live_assistance (G_GNUC_UNUSED GtkWidget *widget, Chem3dWindow *window)
 {
-	window->GetApplication ()->OnLiveAssistance ();
+	window->GetApplication ()->OnLiveAssistance (window->GetScreen ());
 }
 
 static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED Chem3dWindow *window)
@@ -228,7 +228,7 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED Chem3dWindo
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
-		"published by the Free Software Foundation; either version 2 of the\n"
+		"published by the Free Software Foundation; either version 3 of the\n"
 		"License, or (at your option) any later version.\n\n"
 		"This program is distributed in the hope that it will be useful,\n"
 		"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
