@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint text plugin
- * texttool.cc 
+ * texttool.cc
  *
  * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -121,7 +121,7 @@ bool gcpTextTool::OnClicked ()
 		m_Active->OnButtonPressed (m_x0, m_y0);
 		m_CurNode = ((gcp::Text*) m_pObject)->SaveSelected ();
 		m_InitNode = ((gcp::Text*) m_pObject)->SaveSelected ();
-		m_pView->GetDoc ()->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", false);
+		static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ())->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", false);
 		text->SetEditor (this);
 		if (create)
 			BuildTagsList ();
@@ -144,65 +144,80 @@ void gcpTextTool::OnDrag ()
 bool gcpTextTool::OnKeyPress (GdkEventKey* event)
 {
 	if (m_Active) {
+		gcp::Text *text = static_cast < gcp::Text * > (m_Active->GetClient ());
 		if (event->state & GDK_CONTROL_MASK) {
 			switch (event->keyval) {
-			case GDK_Right:
-			case GDK_Left:
-			case GDK_Up:
-			case GDK_Down:
-			case GDK_End:
-			case GDK_Home:
-			case GDK_Delete:
-			case GDK_KP_Delete:
-			case GDK_BackSpace:
+			case GDK_KEY_Right:
+			case GDK_KEY_Left:
+			case GDK_KEY_Up:
+			case GDK_KEY_Down:
+			case GDK_KEY_End:
+			case GDK_KEY_Home:
+			case GDK_KEY_Delete:
+			case GDK_KEY_KP_Delete:
+			case GDK_KEY_BackSpace:
 				break;
-			case GDK_a:
+			case GDK_KEY_a:
 				m_pView->OnSelectAll ();
 				return true;
-			case GDK_z:
+			case GDK_KEY_z:
 				m_pView->GetDoc()->OnUndo ();
 				return true;
-			case GDK_Z:
+			case GDK_KEY_Z:
 				m_pView->GetDoc()->OnRedo ();
 				return true;
-			case GDK_c:
+			case GDK_KEY_c:
 				CopySelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 				return true;
-			case GDK_v:
+			case GDK_KEY_v:
 				PasteSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 				return true;
-			case GDK_x:
+			case GDK_KEY_x:
 				CutSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 				return true;
-			case GDK_i:
+			case GDK_KEY_i:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				m_Style = (m_Style == PANGO_STYLE_NORMAL)? PANGO_STYLE_ITALIC: PANGO_STYLE_NORMAL;
 				SelectBestFontFace ();
 				BuildTagsList ();
 				return true;
-			case GDK_u:
+			case GDK_KEY_u:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				gtk_combo_box_set_active (m_UnderlineBox, ((m_Underline == gccv::TextDecorationDefault)? 0: 1));
 				return true;
-			case GDK_b:
+			case GDK_KEY_b:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				m_Weight = (m_Weight == PANGO_WEIGHT_NORMAL)? PANGO_WEIGHT_BOLD: PANGO_WEIGHT_NORMAL;
 				SelectBestFontFace ();
 				BuildTagsList ();
 				return true;
-			case GDK_k:
+			case GDK_KEY_k:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				gtk_toggle_button_set_active (m_StrikethroughBtn, !m_Strikethrough);
 				return true;
-			case GDK_plus:
-			case GDK_dead_circumflex:
-			case GDK_KP_Add:
-			case GDK_asciicircum:
+			case GDK_KEY_plus:
+			case GDK_KEY_dead_circumflex:
+			case GDK_KEY_KP_Add:
+			case GDK_KEY_asciicircum:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				m_Position = (m_Position == gccv::Superscript)? gccv::Normalscript: gccv::Superscript;
 				BuildTagsList ();
 				return true;
-			case GDK_equal:
-			case GDK_underscore:
+			case GDK_KEY_equal:
+			case GDK_KEY_underscore:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				m_Position = (m_Position == gccv::Subscript)? gccv::Normalscript: gccv::Subscript;
 				BuildTagsList ();
 				return true;
-			case GDK_space: {
+			case GDK_KEY_space: {
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				gccv::Text *saved = m_Active;
 				m_Active = NULL;
 				UpdateTagsList ();
@@ -210,34 +225,44 @@ bool gcpTextTool::OnKeyPress (GdkEventKey* event)
 				BuildTagsList ();
 				return true;
 			}
-			case GDK_l:
+			case GDK_KEY_l:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				if (m_Active)
 					m_Active->SetJustification (GTK_JUSTIFY_LEFT, true);
 				return true;
-			case GDK_r:
+			case GDK_KEY_r:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				if (m_Active)
 					m_Active->SetJustification (GTK_JUSTIFY_RIGHT, true);
 				return true;
-			case GDK_j:
+			case GDK_KEY_j:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				if (m_Active)
 					m_Active->SetJustification (GTK_JUSTIFY_FILL, true);
 				return true;
-			case GDK_m:
+			case GDK_KEY_m:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
 				if (m_Active)
 					m_Active->SetJustification (GTK_JUSTIFY_CENTER, true);
 				return true;
-			case GDK_w:
-				if (m_Active) {
-					double w = m_Active->GetInterline ();
-					if (w == 0.)
+			case GDK_KEY_w: {
+				if (text->GetGlobalTag () != gccv::Invalid)
 						return true;
-					w -= 1.;
-					m_Active->SetInterline ((w > 0.? w: 0.), true);
-				}
+				double w = m_Active->GetInterline ();
+				if (w == 0.)
+					return true;
+				w -= 1.;
+				m_Active->SetInterline ((w > 0.? w: 0.), true);
 				return true;
-			case GDK_W:
-				if (m_Active) 
-					m_Active->SetInterline (m_Active->GetInterline () + 1., true);
+			}
+			case GDK_KEY_W:
+				if (text->GetGlobalTag () != gccv::Invalid)
+						return true;
+				m_Active->SetInterline (m_Active->GetInterline () + 1., true);
 				return true;
 			default:
 				break;
@@ -260,6 +285,8 @@ void gcpTextTool::Activate ()
 {
 	if (!m_Active)
 		UpdateTagsList ();
+	if (m_PropertyPage && m_pObject)
+		gtk_widget_set_sensitive (m_PropertyPage, m_Active && static_cast < gcp::Text * > (m_pObject)->GetGlobalTag () == gccv::Invalid);
 }
 
 bool gcpTextTool::Deactivate ()
@@ -375,16 +402,16 @@ bool gcpTextTool::Unselect ()
 	}
 	m_CurNode = m_InitNode = NULL;
 	if (!*text) {
-		Object* pMol = pObj->GetMolecule ();	//if pObj is a fragment
-		if (pMol)
-			pObj = pMol;
-		gcu::Object *parent = pObj->GetParent ();
+		char const *id = pObj->GetParent ()->GetId ();
+		std::string parent_id = (id)? id: "";
 		m_pView->GetDoc ()->Remove (pObj);
 		m_pView->GetDoc ()->AbortOperation ();
-		parent->EmitSignal (gcp::OnChangedSignal);
+		gcu::Object *parent = (id)? m_pView->GetDoc ()->GetDescendant (parent_id.c_str ()): NULL;
+		if (parent)
+			parent->EmitSignal (gcp::OnChangedSignal);
 	}
 	m_pView->GetDoc ()->FinishOperation ();
-	m_pView->GetDoc ()->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", m_pView->GetDoc ()->HasChildren ());
+	static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ())->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", m_pView->GetDoc ()->HasChildren ());
 	return true;
 }
 
@@ -576,7 +603,7 @@ bool gcpTextTool::OnUndo ()
 	text->LoadSelected (node);
 	m_UndoList.pop_front ();
 	gcp::Document *pDoc = m_pView->GetDoc ();
-	gcp::Window *pWin = pDoc->GetWindow ();
+	gcp::Window *pWin = static_cast < gcp::Window * > (pDoc->GetWindow ());
 	if (m_UndoList.empty() && !pDoc->CanUndo ())
 		pWin->ActivateActionWidget ("/MainMenu/EditMenu/Undo", false);
 	m_RedoList.push_front(m_CurNode);
@@ -593,7 +620,7 @@ bool gcpTextTool::OnRedo ()
 	gcp::TextObject *text = dynamic_cast <gcp::TextObject*> (m_Active->GetClient ());
 	text->LoadSelected (node);
 	m_RedoList.pop_front ();
-	gcp::Window *pWin = m_pView->GetDoc ()->GetWindow ();
+	gcp::Window *pWin = static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ());
 	if (m_RedoList.empty ())
 		pWin->ActivateActionWidget ("/MainMenu/EditMenu/Redo", false);
 	m_UndoList.push_front (m_CurNode);
@@ -604,7 +631,7 @@ bool gcpTextTool::OnRedo ()
 
 void gcpTextTool::PushNode (xmlNodePtr node)
 {
-	gcp::Window *pWin = m_pView->GetDoc ()->GetWindow ();
+	gcp::Window *pWin = static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ());
 	while (!m_RedoList.empty ()) {
 		xmlUnlinkNode (m_RedoList.front ());
 		xmlFreeNode (m_RedoList.front ());
@@ -625,7 +652,7 @@ void gcpTextTool::OnGetData (GtkClipboard *clipboard, GtkSelectionData *selectio
 	if (info) {
 		if (gcp::ClipboardTextData) {
 			g_free (gcp::ClipboardTextData);
-		} 
+		}
 		gcp::Text *text = new gcp::Text ();
 		text->Load (pDoc->children->children);
 		gcp::ClipboardTextData = g_strdup (text->GetBuffer ().c_str ());
@@ -637,7 +664,7 @@ void gcpTextTool::OnGetData (GtkClipboard *clipboard, GtkSelectionData *selectio
 		gtk_selection_data_set (selection_data, gdk_atom_intern (GCHEMPAINT_ATOM_NAME, FALSE), 8,  (const guchar*) gcp::ClipboardData, size);
 	}
 	if (clipboard == gtk_clipboard_get (GDK_SELECTION_CLIPBOARD))
-			m_pView->GetDoc ()->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Paste", true);
+			static_cast < gcp::Window * > (m_pView->GetDoc ()->GetWindow ())->ActivateActionWidget ("/MainMenu/EditMenu/Paste", true);
 }
 
 void gcpTextTool::UpdateTagsList ()
@@ -645,12 +672,22 @@ void gcpTextTool::UpdateTagsList ()
 	if (!m_FamilyList)
 		return;
 	gcp::Theme *pTheme = m_pApp->GetActiveDocument ()->GetTheme ();
-	m_FamilyName = pTheme->GetTextFontFamily ();
-	m_Style = pTheme->GetFontStyle ();
-	m_Weight = pTheme->GetFontWeight ();
-	m_Stretch = pTheme->GetFontStretch ();
-	m_Variant = pTheme->GetFontVariant ();
-	m_Size = pTheme->GetFontSize ();
+	gcp::Text *text = (m_Active)? static_cast < gcp::Text * > (m_Active->GetClient ()): NULL;
+	if (!text || text->GetGlobalTag () == gccv::Invalid) {
+		m_FamilyName = pTheme->GetTextFontFamily ();
+		m_Style = pTheme->GetTextFontStyle ();
+		m_Weight = pTheme->GetTextFontWeight ();
+		m_Stretch = pTheme->GetTextFontStretch ();
+		m_Variant = pTheme->GetTextFontVariant ();
+		m_Size = pTheme->GetTextFontSize ();
+	} else {
+		m_FamilyName = pTheme->GetFontFamily ();
+		m_Style = pTheme->GetFontStyle ();
+		m_Weight = pTheme->GetFontWeight ();
+		m_Stretch = pTheme->GetFontStretch ();
+		m_Variant = pTheme->GetFontVariant ();
+		m_Size = pTheme->GetFontSize ();
+	}
 	m_Rise = 0;
 	m_Underline = gccv::TextDecorationNone;
 	m_Strikethrough = gccv::TextDecorationNone;
@@ -758,21 +795,25 @@ void gcpTextTool::BuildTagsList ()
 	if (!m_Active)
 		return;
 	gccv::TextTagList *l = new gccv::TextTagList ();
-	l->push_front (new gccv::FamilyTextTag (m_FamilyName));
-	l->push_front (new gccv::StyleTextTag (m_Style));
-	l->push_front (new gccv::WeightTextTag (m_Weight));
-	l->push_front (new gccv::StretchTextTag (m_Stretch));
-	l->push_front (new gccv::VariantTextTag (m_Variant));
-	l->push_front (new gccv::SizeTextTag (m_Size));
-	l->push_front (new gccv::UnderlineTextTag (m_Underline));
-	l->push_front (new gccv::StrikethroughTextTag (m_Strikethrough));
-	l->push_front (new gccv::RiseTextTag (m_Rise));
-	l->push_front (new gccv::ForegroundTextTag (m_Color));
-	l->push_front (new gccv::PositionTextTag (m_Position, m_Size));
+	gccv::Tag tag = static_cast < gcp::Text * > (m_Active->GetClient ())->GetGlobalTag ();
+	if (tag == gccv::Invalid) {
+		l->push_front (new gccv::FamilyTextTag (m_FamilyName));
+		l->push_front (new gccv::StyleTextTag (m_Style));
+		l->push_front (new gccv::WeightTextTag (m_Weight));
+		l->push_front (new gccv::StretchTextTag (m_Stretch));
+		l->push_front (new gccv::VariantTextTag (m_Variant));
+		l->push_front (new gccv::SizeTextTag (m_Size));
+		l->push_front (new gccv::UnderlineTextTag (m_Underline));
+		l->push_front (new gccv::StrikethroughTextTag (m_Strikethrough));
+		l->push_front (new gccv::RiseTextTag (m_Rise));
+		l->push_front (new gccv::ForegroundTextTag (m_Color));
+		l->push_front (new gccv::PositionTextTag (m_Position, m_Size));
+	} else if (tag == gcp::StoichiometryTag)
+		l->push_front (new gcp::StoichiometryTextTag (static_cast < double > (m_Size) / PANGO_SCALE));
 	m_Active->SetCurTagList (l);
 	m_Dirty = false;
 	if (m_pView)
-		gtk_window_present (m_pView->GetDoc ()->GetWindow ()->GetWindow ());
+		gtk_window_present (static_cast < gcugtk::Window * > (m_pView->GetDoc ()->GetWindow ())->GetWindow ());
 }
 
 static void on_select_family (GtkTreeSelection *selection, gcpTextTool *tool)
@@ -939,10 +980,11 @@ GtkWidget *gcpTextTool::GetPropertyPage ()
 	go_color_selector_set_allow_alpha (m_ColorSelector, false);
 	m_ForeSignal = g_signal_connect (G_OBJECT (m_ColorSelector), "activate", G_CALLBACK (on_fore_color_changed), this);
 	gtk_widget_show (GTK_WIDGET (m_ColorSelector));
-	gtk_table_attach (GTK_TABLE (builder->GetWidget ("table2")), GTK_WIDGET (m_ColorSelector), 1, 2, 0, 1, (GtkAttachOptions) 0, (GtkAttachOptions) 0, 0, 0);
-	GtkWidget *res = builder->GetRefdWidget ("fontsel");
+	g_object_set (G_OBJECT (m_ColorSelector), "halign", GTK_ALIGN_START, NULL);
+	gtk_grid_attach (GTK_GRID (builder->GetWidget ("details")), GTK_WIDGET (m_ColorSelector), 1, 1, 1, 1);
+	m_PropertyPage = builder->GetRefdWidget ("fontsel");
 	delete builder;
-	return res;
+	return m_PropertyPage;
 }
 
 void gcpTextTool::OnSelectFamily (GtkTreeSelection *selection)
@@ -1067,7 +1109,7 @@ void gcpTextTool::SetSizeFull (bool update_list, bool apply)
 		bool found = false;
 		GtkTreeSelection *selection = gtk_tree_view_get_selection (m_SizesTree);
 		g_signal_handler_block (selection, m_SizeSignal);
-		
+
 		gtk_tree_model_get_iter_first (GTK_TREE_MODEL (m_SizeList), &iter);
 		for (unsigned i = 0; i < G_N_ELEMENTS (font_sizes) && !found; i++) {
 			if (font_sizes[i] * PANGO_SCALE == m_Size) {
@@ -1079,7 +1121,7 @@ void gcpTextTool::SetSizeFull (bool update_list, bool apply)
 
 			gtk_tree_model_iter_next (GTK_TREE_MODEL (m_SizeList), &iter);
 		}
-		
+
 		if (!found)
 			gtk_tree_selection_unselect_all (selection);
 		g_signal_handler_unblock (selection, m_SizeSignal);
