@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/calc/gchemcalc.cc 
+ * programs/calc/gchemcalc.cc
  *
- * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -230,7 +230,7 @@ bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool
 			gog_graph_set_size (gr, GetImageWidth (), GetImageHeight ());
 			gog_graph_export_image (gr, format, output, -1., -1.);
 			g_object_unref (gr);
-			
+
 		}
 		g_object_unref (file);
 	}
@@ -255,24 +255,24 @@ static void on_help (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer dat
 	App->OnHelp ();
 }
 
-static void on_web (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data)
+static void on_web (GtkWidget *widget, G_GNUC_UNUSED gpointer data)
 {
-	App->OnWeb ();
+	App->OnWeb (gtk_widget_get_screen (widget));
 }
 
-static void on_mail (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data)
+static void on_mail (GtkWidget *widget, G_GNUC_UNUSED gpointer data)
 {
-	App->OnMail ();
+	App->OnMail (gtk_widget_get_screen (widget));
 }
 
-static void on_live_assistance (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer dataw)
+static void on_live_assistance (GtkWidget *widget, G_GNUC_UNUSED gpointer dataw)
 {
-	App->OnLiveAssistance ();
+	App->OnLiveAssistance (gtk_widget_get_screen (widget));
 }
 
-static void on_bug (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data)
+static void on_bug (GtkWidget *widget, G_GNUC_UNUSED gpointer data)
 {
-	App->OnBug ();
+	App->OnBug (gtk_widget_get_screen (widget));
 }
 
 static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
@@ -284,7 +284,7 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
-		"published by the Free Software Foundation; either version 2 of the\n"
+		"published by the Free Software Foundation; either version 3 of the\n"
 		"License, or (at your option) any later version.\n\n"
 		"This program is distributed in the hope that it will be useful,\n"
 		"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
@@ -331,7 +331,7 @@ static void cb_entry_active (GtkEntry *entry, gpointer data)
 		DimensionalValue weight = App->formula.GetMolecularWeight (artificial);
 		char *weightstr = (artificial)?
 			g_strdup_printf ("(%.0f g.mol<sup>-1</sup>)",weight.GetAsDouble ()):
-			g_strdup (weight.GetAsString ());			
+			g_strdup (weight.GetAsString ());
 		gtk_label_set_markup (App->weight, weightstr);
 		g_free (weightstr);
 		// Composition
@@ -484,17 +484,17 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 	case 0: {
 			GsfXMLOut *xout;
 			char *old_num_locale, *old_monetary_locale;
-		
+
 			old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
 			go_setlocale (LC_NUMERIC, "C");
 			old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
 			go_setlocale (LC_MONETARY, "C");
 			go_locale_untranslated_booleans ();
-		
+
 			xout = gsf_xml_out_new (output);
 			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
 			g_object_unref (xout);
-		
+
 			/* go_setlocale restores bools to locale translation */
 			go_setlocale (LC_MONETARY, old_monetary_locale);
 			g_free (old_monetary_locale);
@@ -516,7 +516,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 		true;
 	if (res) {
 		osize = gsf_output_size (output);
-				
+
 		buffer = (guchar*) g_malloc (osize);
 		memcpy (buffer, gsf_output_memory_get_bytes (omem), osize);
 		gsf_output_close (output);
@@ -674,7 +674,7 @@ gboolean cb_print_version (G_GNUC_UNUSED const gchar *option_name, G_GNUC_UNUSED
 	return TRUE;
 }
 
-static GOptionEntry options[] = 
+static GOptionEntry options[] =
 {
   { "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, "prints GChemCalc version", NULL },
    { NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
@@ -708,18 +708,18 @@ int main (int argc, char *argv[])
 	}
 
 	App = new GChemCalc ();
-	
+
 	/* Initialize plugins manager */
 	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 
 	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/gchemcalc.ui", GETTEXT_PACKAGE);
 	App->window = GTK_WINDOW (builder->GetRefdWidget ("gchemcalc"));
 	gtk_window_set_icon_name (App->window, App->GetIconName ().c_str ());
-	g_signal_connect (GTK_OBJECT (App->window), "destroy",
+	g_signal_connect (G_OBJECT (App->window), "destroy",
 		 G_CALLBACK (gtk_main_quit),
 		 NULL);
-	
-	GtkWidget *vbox = builder->GetWidget ("vbox1");
+
+	GtkWidget *grid = builder->GetWidget ("calc-grid");
 	GtkUIManager *ui_manager = gtk_ui_manager_new ();
 	App->SetUIManager (ui_manager);
 	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
@@ -735,8 +735,7 @@ int main (int argc, char *argv[])
 		exit (EXIT_FAILURE);
 	}
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
-	gtk_box_reorder_child (GTK_BOX (vbox), bar, 0);
+	gtk_grid_attach (GTK_GRID (grid), bar, 0, 0, 2, 1);
 	App->markup = GTK_LABEL (builder->GetWidget ("markup"));
 	App->raw = GTK_LABEL (builder->GetWidget ("raw"));
 	App->weight = GTK_LABEL (builder->GetWidget ("weight"));
@@ -764,7 +763,7 @@ int main (int argc, char *argv[])
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 150);
 	gtk_tree_view_append_column (tree, column);
-	
+
 	// Add isotopic pattern chart
 	App->mono = GTK_LABEL (builder->GetWidget ("mono"));
 	App->monomass = GTK_LABEL (builder->GetWidget ("monomass"));
@@ -772,7 +771,8 @@ int main (int argc, char *argv[])
 	App->graph_widget = go_graph_widget_new (NULL);
 	g_signal_connect_swapped (App->graph_widget, "size-allocate", G_CALLBACK (GChemCalc::OnSize), App);
 	gtk_widget_show (App->graph_widget);
-	gtk_box_pack_end (GTK_BOX (App->pattern_page), App->graph_widget, TRUE, TRUE, 0);
+	gtk_grid_attach (GTK_GRID (App->pattern_page), App->graph_widget, 0, 1, 2, 1);
+	g_object_set (G_OBJECT (App->graph_widget), "hexpand", true, "vexpand", true, NULL);
 	App->graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (App->graph_widget));
 	App->chart = go_graph_widget_get_chart (GO_GRAPH_WIDGET (App->graph_widget));
 	App->plot = (GogPlot *) gog_plot_new_by_name ("GogXYPlot");
@@ -792,7 +792,7 @@ int main (int argc, char *argv[])
 
 	gtk_widget_hide (App->pattern_page);
 	GtkWidget *w = builder->GetWidget ("entry");
-	g_signal_connect (GTK_OBJECT (w), "activate",
+	g_signal_connect (G_OBJECT (w), "activate",
 		 G_CALLBACK (cb_entry_active),
 		 App->window);
 	gcu_element_load_databases ("isotopes", NULL);
@@ -802,7 +802,7 @@ int main (int argc, char *argv[])
 		cb_entry_active (GTK_ENTRY (w), App->window);
 	}
 
-	w = builder->GetWidget ("notebook1");
+	w = builder->GetWidget ("calc-book");
 	g_signal_connect (w, "switch-page", G_CALLBACK (on_page), NULL);
 	on_page (NULL, NULL, 0); // force menus deactivation
 
